package com.gic.auth.service.impl;

import com.gic.auth.constant.DeleteFlagConstants;
import com.gic.auth.dao.mapper.TabAuditorAuditedGroupRelMapper;
import com.gic.auth.dao.mapper.TabAuditorMapper;
import com.gic.auth.dto.AuditorAuditedGroupRelDTO;
import com.gic.auth.dto.AuditorDTO;
import com.gic.auth.entity.TabAuditor;
import com.gic.auth.entity.TabAuditorAuditedGroupRel;
import com.gic.auth.qo.AuditorListQO;
import com.gic.auth.service.AuditorService;
import com.gic.commons.util.GlobalInfo;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 *
 * @Description:
 * @author zhiwj
 * @date 2019-09-19 16:40
 */
@Service
public class AuditorServiceImpl implements AuditorService {

    @Autowired
    private TabAuditorMapper tabAuditorMapper;
    @Autowired
    private TabAuditorAuditedGroupRelMapper auditorAuditedGroupRelMapper;

    @Override
    public boolean validAuditorNameIsRepeat(Integer enterpriseId, String auditorName, Integer auditorId) {
        AuditorDTO auditorDTO = new AuditorDTO();
        auditorDTO.setAuditorId(auditorId);
        auditorDTO.setEnterpriseId(enterpriseId);
        auditorDTO.setAuditorName(auditorName);
        TabAuditor auditor = tabAuditorMapper.getFirstAuditor(auditorDTO);
        return auditor != null;
    }

    @Override
    public boolean validPhoneIsRepeat(Integer enterpriseId, String phone, Integer auditorId) {
        AuditorDTO auditorDTO = new AuditorDTO();
        auditorDTO.setAuditorId(auditorId);
        auditorDTO.setEnterpriseId(enterpriseId);
        auditorDTO.setPhone(phone);
        TabAuditor auditor = tabAuditorMapper.getFirstAuditor(auditorDTO);
        return auditor != null;
    }

    @Override
    public boolean validOpenidIsRepeat(Integer enterpriseId, String openid, Integer auditorId) {
        AuditorDTO auditorDTO = new AuditorDTO();
        auditorDTO.setAuditorId(auditorId);
        auditorDTO.setEnterpriseId(enterpriseId);
        auditorDTO.setOpenid(openid);
        TabAuditor auditor = tabAuditorMapper.getFirstAuditor(auditorDTO);
        return auditor != null;
    }

    @Override
    public Integer save(AuditorDTO copy) {
        TabAuditor auditor = new TabAuditor();
        auditor.setEnterpriseId(copy.getEnterpriseId());
        auditor.setAuditorName(copy.getAuditorName());
        auditor.setPhone(copy.getPhone());
        auditor.setUserId(copy.getUserId());
        auditor.setIsUse(copy.getIsUse());
        auditor.setDeleteFlag(DeleteFlagConstants.NORMAL_STATUS);
        auditor.setCreateTime(new Date());
        tabAuditorMapper.insertSelective(auditor);
        return auditor.getAuditorId();
    }

    @Override
    public Integer update(AuditorDTO copy) {
        TabAuditor auditor = new TabAuditor();
        auditor.setAuditorId(copy.getAuditorId());
        auditor.setEnterpriseId(copy.getEnterpriseId());
        auditor.setAuditorName(copy.getAuditorName());
        auditor.setOpenid(copy.getOpenid());
        auditor.setPhone(copy.getPhone());
        auditor.setUserId(copy.getUserId());
        auditor.setIsUse(copy.getIsUse());
        return tabAuditorMapper.updateByPrimaryKeySelective(auditor);
    }

    @Override
    public TabAuditor getAuditor(Integer auditorId) {
        TabAuditor auditor = tabAuditorMapper.selectByPrimaryKey(auditorId);
        if (auditor != null && auditor.getDeleteFlag() == DeleteFlagConstants.NORMAL_STATUS) {
            return auditor;
        }
        return null;
    }

    @Override
    public Integer delAuditor(Integer auditorId) {
        return tabAuditorMapper.delAuditor(auditorId);
    }

    @Override
    public Page<TabAuditor> pageAuditor(AuditorListQO auditorListQO) {
        if (auditorListQO.getAuditedGroupId() != null) {
            AuditorAuditedGroupRelDTO auditedGroupRelDTO = new AuditorAuditedGroupRelDTO();
            auditedGroupRelDTO.setAuditedGroupId(auditorListQO.getAuditedGroupId());
            List<TabAuditorAuditedGroupRel> relList = auditorAuditedGroupRelMapper.listRel(auditedGroupRelDTO);
            if (CollectionUtils.isEmpty(relList)) {
                return new Page<>();
            } else {
                List<Integer> auditorIdList = relList.stream().map(TabAuditorAuditedGroupRel::getAuditorId).collect(Collectors.toList());
                auditorListQO.setAuditorIdList(auditorIdList);
            }
        }
        PageHelper.startPage(auditorListQO.getCurrentPage(), auditorListQO.getPageSize());
        return tabAuditorMapper.listAuditor(auditorListQO);
    }

    @Override
    public List<TabAuditor> listAuditor(AuditorListQO auditorListQO) {
        return tabAuditorMapper.listAuditor(auditorListQO);
    }

    @Override
    public TabAuditor getAuditorByUserId(Integer enterpriseId, Integer userId) {
        AuditorDTO auditorDTO = new AuditorDTO();
        auditorDTO.setEnterpriseId(enterpriseId);
        auditorDTO.setUserId(userId);
        return tabAuditorMapper.getFirstAuditor(auditorDTO);
    }

    @Override
    public TabAuditor getAuditorByOpenid(String openid) {
        return tabAuditorMapper.getAuditorByOpenid(openid);
    }
}
